@@ -12,10 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-//! Compute API support.
+//! Compute API.
+//!
+//! Supported API groups:
+//!
+//! * [server management](servers/index.html)
+//!
+//! See the [api module](api/index.html) for low-level API access.
 
+pub mod api;
 mod protocol;
-pub mod servermanager;
-
-pub use self::servermanager::ServerFilters;
-pub use self::servermanager::servers;
+pub mod servers;
