@@ -30,8 +30,7 @@
 
 use super::super::{ApiResult, Session};
 use super::super::auth::Method as AuthMethod;
-use super::super::session::ServiceApi;
-use super::super::utils::IntoId;
+use super::super::service::{IntoId, ServiceApi};
 use super::api::ComputeV2;
 use super::protocol;
 
@@ -155,11 +154,11 @@ pub mod test {
 
     use hyper;
 
-    use super::super::super::Session;
     use super::super::super::auth::{NoAuth, SimpleToken};
+    use super::super::super::session::test;
+    use super::super::api::test as api_test;
     use super::manager;
 
-    // Copied from compute API reference.
     const SERVERS_RESPONSE: &'static str = r#"
     {
         "servers": [
@@ -180,10 +179,11 @@ pub mod test {
         ]
     }"#;
 
-    mock_connector!(MockServers {
-        "http://127.0.2.1" => String::from("HTTP/1.1 200 OK\r\n\
-                                           Server: Mock.Mock\r\n\
-                                           \r\n") + SERVERS_RESPONSE
+    mock_connector_in_order!(MockServers {
+        String::from("HTTP/1.1 200 OK\r\nServer: Mock.Mock\r\n\
+                     \r\n") + api_test::ONE_VERSION_RESPONSE
+        String::from("HTTP/1.1 200 OK\r\nServer: Mock.Mock\r\n\
+                     \r\n") + SERVERS_RESPONSE
     });
 
     #[test]
@@ -191,7 +191,7 @@ pub mod test {
         let auth = NoAuth::new("http://127.0.2.1/v2.1").unwrap();
         let cli = hyper::Client::with_connector(MockServers::default());
         let token = SimpleToken(String::from("abcdef"));
-        let session = Session::new_with_params(auth, cli, token);
+        let session = test::new_with_params(auth, cli, token, None);
 
         let mgr = manager(&session);
         let srvs = mgr.list().unwrap();
