@@ -82,11 +82,13 @@ pub mod auth;
 mod common;
 #[cfg(feature = "compute")]
 pub mod compute;
+pub mod http;
 mod identity;
-pub mod session;
+pub mod service;
+mod session;
 mod utils;
 
 pub use common::ApiError;
 pub use common::ApiResult;
-pub use common::ServiceType;
+pub use common::ApiVersion;
 pub use session::Session;
